# Table of Contents

- [configure-architecture-executive-dashboard](<./configure-architecture-executive-dashboard.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring the Architecture Executive Dashboard](<./Configuring-the-Architecture-Executive-Dashboard.md>)
  - [Global Filter](<./Configuring-the-Architecture-Executive-Dashboard/Global-Filter.md>)
  - [Views](<./Configuring-the-Architecture-Executive-Dashboard/Views.md>)
  - [Creating a View](<./Configuring-the-Architecture-Executive-Dashboard/Creating-a-View.md>)
  - [Managing Views](<./Configuring-the-Architecture-Executive-Dashboard/Managing-Views.md>)
  - [Best Practices](<./Configuring-the-Architecture-Executive-Dashboard/Best-Practices.md>)
  - [Start with Basic Filters](<./Configuring-the-Architecture-Executive-Dashboard/Start-with-Basic-Filters.md>)
  - [Configure Advanced Filters](<./Configuring-the-Architecture-Executive-Dashboard/Configure-Advanced-Filters.md>)
  - [Avoid Over-Scoping Filters](<./Configuring-the-Architecture-Executive-Dashboard/Avoid-Over-Scoping-Filters.md>)
